Terms and Conditions
====================

Quality
-------

RecaptureDocs utilizes real human intelligence to retype pages. As a
result, quality can vary from job to job. There is no guarantee of
quality for the resulting output.

Confidentiality and Intellectual Property
-----------------------------------------

The client's content is stored with the strictest confidence. Documents
are stored on a secure server managed only by trusted individuals. The
content (currently pages) is farmed out to the individual workers who
then of course have access to the content for the purposes of retyping.

In the future, typists will be expected to agree to the following terms
before retrieving any content.

    I agree that the document images and the information represented by
    those images (content) is property of the original submitter. As a
    typist, I agree not to use this information for any purpose other
    than to produce the typed copy. After succcessful submission, I will
    purge any residual content.

RecaptureDocs makes a best effort to protect the confidentiality of
client content. In return, the client agrees not to hold RecaptureDocs
or its affiliates
responsible for any breach of copyright or other intellectual property
violation enacted by the typists. This agreement does not preclude the
client's right to pursue legal action against a typist directly.
